#ifndef NT2_INCLUDE_CONSTANTS_TWOTO31_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_TWOTO31_HPP_INCLUDED

#include <nt2/constant/include/constants/twoto31.hpp>

#endif
